# asdf-inspect

An auxiliary library for the [virtualenv-asdf][virtualenv-asdf] and [tox-asdf-redux][tox-asdf-redux] plugins.

## Limitations

Only CPython is supported at the moment.


NOTE: this is modified from [pyenv-inspect][pyenv-inspect] by un-def.

[pyenv-inspect]: https://github.com/un-def/pyenv-inspect
[virtualenv-asdf]: https://github.com/lanshark/virtualenv-asdf
[tox-asdf-redux]: https://github.com/lanshark/tox-asdf-redux
